@@ -39,7 +39,7 @@ class MALWidget;
 
 class MALWidgetSetup : public ConduitConfigBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	MALWidgetSetup(TQWidget *,const char *);
