@@ -228,8 +228,8 @@ void MemoWidget::setupWidget()
 
 	fCatList = new TQComboBox(this);
 	grid->addWidget(fCatList, 0, 1);
-	connect(fCatList, TQT_SIGNAL(activated(int)),
-		this, TQT_SLOT(slotSetCategory(int)));
+	connect(fCatList, TQ_SIGNAL(activated(int)),
+		this, TQ_SLOT(slotSetCategory(int)));
 	TQWhatsThis::add(fCatList,
 		i18n("Select the category of addresses\n"
 			"to display here."));
@@ -241,10 +241,10 @@ void MemoWidget::setupWidget()
 
 	fListBox = new TQListBox(this);
 	grid->addMultiCellWidget(fListBox, 1, 1, 0, 1);
-	connect(fListBox, TQT_SIGNAL(highlighted(int)),
-		this, TQT_SLOT(slotShowMemo(int)));
-	connect(fListBox, TQT_SIGNAL(selectionChanged()),
-		this,TQT_SLOT(slotUpdateButtons()));
+	connect(fListBox, TQ_SIGNAL(highlighted(int)),
+		this, TQ_SLOT(slotShowMemo(int)));
+	connect(fListBox, TQ_SIGNAL(selectionChanged()),
+		this,TQ_SLOT(slotUpdateButtons()));
 	TQWhatsThis::add(fListBox,
 		i18n("This list displays all the memos\n"
 			"in the selected category. Click on\n"
@@ -263,7 +263,7 @@ void MemoWidget::setupWidget()
 
 	button = new TQPushButton(i18n("Import Memo..."), this);
 	grid->addWidget(button, 2, 0);
-	connect(button, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotImportMemo()));
+	connect(button, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotImportMemo()));
 	wt = KPilotSettings::internalEditors() ?
 		i18n	("Read a text file and add it to the Pilot's memo database.") :
 		i18n("<qt><i>Import is disabled by the 'internal editors' setting.</i></qt>");
@@ -271,15 +271,15 @@ void MemoWidget::setupWidget()
 
 	fExportButton = new TQPushButton(i18n("Export Memo..."), this);
 	grid->addWidget(fExportButton, 2, 1);
-	connect(fExportButton, TQT_SIGNAL(clicked()), this,
-		TQT_SLOT(slotExportMemo()));
+	connect(fExportButton, TQ_SIGNAL(clicked()), this,
+		TQ_SLOT(slotExportMemo()));
 	TQWhatsThis::add(fExportButton,
 		i18n("Write the selected memo to a file."));
 
 	fDeleteButton = new TQPushButton(i18n("Delete Memo"), this);
 	grid->addWidget(fDeleteButton, 3, 1);
-	connect(fDeleteButton, TQT_SIGNAL(clicked()), this,
-		TQT_SLOT(slotDeleteMemo()));
+	connect(fDeleteButton, TQ_SIGNAL(clicked()), this,
+		TQ_SLOT(slotDeleteMemo()));
 	wt = KPilotSettings::internalEditors() ?
 		i18n("Delete the selected memo.") :
 		i18n("<qt><i>Deleting is disabled by the 'internal editors' setting.</i></qt>") ;
@@ -287,7 +287,7 @@ void MemoWidget::setupWidget()
 
 	button = new TQPushButton(i18n("Add Memo"), this);
 	grid->addWidget(button, 3, 0);
-	connect(button, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotAddMemo()));
+	connect(button, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotAddMemo()));
 	TQWhatsThis::add(button,i18n("Add a new memo to the database."));
 }
 
