@@ -215,7 +215,7 @@ class DeviceCommThread : public TQObject, public TQThread
 {
 friend class KPilotDeviceLink;
 
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
